@@ -102,7 +102,7 @@ class CommonActions(object):
             status (boolean)
         """
         wDesc = "Verify if response pattern exist in response data_repository"
-        Utils.testcase_Utils.pNote(wDesc)
+        Utils.testcase_Utils.pNote("KEYWORD: verify_resp_data | Description: {0}".format(wDesc))
 
         status = True
         result = Utils.data_Utils.get_object_from_datarepository(object_key)
@@ -150,6 +150,8 @@ class CommonActions(object):
             All three formats in the above sample block are allowed. If 'type'
             is not provided, value will be converted as string by default.
         """
+        wDesc = "Stores the values to the data_repository"
+        Utils.testcase_Utils.pNote("KEYWORD: store_in_repo | Description: {0}".format(wDesc))
         status = False
         pass_msg = "Value: {0} is stored in a Key: {1} of Warrior data_repository"
 
@@ -233,7 +235,7 @@ class CommonActions(object):
 
         """
         wDesc = "Print the  value of given key in data_repository "
-        Utils.testcase_Utils.pNote(wDesc)
+        Utils.testcase_Utils.pNote("KEYWORD: fetch_in_repo | Description: {0}".format(wDesc))
         status = True
         pass_msg = "Value: {0} is stored in a Key: {1} of Warrior data_repository"
         value = get_object_from_datarepository(datavar)
@@ -260,7 +262,7 @@ class CommonActions(object):
         """
         wDesc = "Verify if value of object_key in data_repository "
         "matches with expected"
-        Utils.testcase_Utils.pNote(wDesc)
+        Utils.testcase_Utils.pNote("KEYWORD: verify_data | Description: {0}".format(wDesc))
         result, value = Utils.data_Utils.verify_data(expected, object_key, type, comparison)
         if result not in ["FALSE", "TRUE"]:
             return result
@@ -291,6 +293,9 @@ class CommonActions(object):
         Sample environmental_variable file is available under
         Warriorspace/Config_file/Samples/Set_ENV_Variable_Sample.json
         """
+        wDesc = "Create a temp environment variable, the value will only stay for the \
+        current Execution"
+        Utils.testcase_Utils.pNote("KEYWORD: set_env_var | Description: {0}".format(wDesc))
         overwrite = overwrite.upper()
         status = False
         if not any([var_key, var_value, filepath]):
@@ -380,7 +385,7 @@ class CommonActions(object):
                 1. status(boolean)
         """
         wdesc = "Verify if the output of the arithmetic expression matches the expected"
-        Utils.testcase_Utils.pNote(wdesc)
+        Utils.testcase_Utils.pNote("KEYWORD: verify_arith_exp | Description: {0}".format(wdesc))
         status = Utils.data_Utils.verify_arith_exp(expression, expected,
                                                    comparison, repo_key)
         return status
@@ -399,7 +404,8 @@ class CommonActions(object):
 
         """
         wdesc = "To get the current timestamp in the format of yyyy-mm-dd hh:mm:ss"
-        Utils.testcase_Utils.pNote(wdesc)
+        Utils.testcase_Utils.pNote("KEYWORD: get_current_timestamp | Description: {0}".\
+            format(wdesc))
         currentdate = datetime_utils.get_current_timestamp()
         print_info("current timestamp : {0}".format(currentdate))
         output_dict = {current_time: currentdate}
@@ -428,7 +434,7 @@ class CommonActions(object):
 
         """
         wdesc = "To get time difference between two timestamps"
-        Utils.testcase_Utils.pNote(wdesc)
+        Utils.testcase_Utils.pNote("KEYWORD: get_time_delta | Description: {0}".format(wdesc))
         start_time = Utils.data_Utils.get_object_from_datarepository(start_time)
         if end_time:
             end_time = Utils.data_Utils.get_object_from_datarepository(end_time)
@@ -438,7 +444,7 @@ class CommonActions(object):
         if max_time_diff:
             if time_delta > int(max_time_diff):
                 print_error("The time difference is greater than max time \
-                 difference so failing the step !")
+                    difference so failing the step !")
                 status = False
                 return status, output_dict
         status = True
