@@ -61,13 +61,15 @@ def warrior_framework_details():
                 version = match.group(2)
 
     user = getpass.getuser()
-    proc1 = subprocess.Popen(['git', 'branch'], stdout=subprocess.PIPE)
-    proc2 = subprocess.Popen(['grep', '*'], stdin=proc1.stdout,
-                             stdout=subprocess.PIPE, stderr=None)
-    proc1.stdout.close() # Allow proc1 to receive a SIGPIPE if proc2 exits.
-    branch = proc2.communicate()[0]
-    branch = branch.decode('utf-8')
-    branch = branch.strip()[1:]
+    if os.getenv("pipmode",None) == "False":
+        #get warriorframework_py3 repo branch
+        proc1 = subprocess.Popen(['git', 'branch'], stdout=subprocess.PIPE)
+        proc2 = subprocess.Popen(['grep', '*'], stdin=proc1.stdout,
+                                 stdout=subprocess.PIPE, stderr=None)
+        proc1.stdout.close() # Allow proc1 to receive a SIGPIPE if proc2 exits.
+        branch = proc2.communicate()[0]
+        branch = branch.decode('utf-8')
+        branch = branch.strip()[1:]
     hostname = platform.node()
 
     if release and version and version_file_path:
@@ -77,7 +79,8 @@ def warrior_framework_details():
         print_info('The Warrior framework user is {0}'.format(user))
         print_info('The Warrior framework Release is{0}'.format(release))
         print_info('The Warrior framework version is{0}'.format(version))
-        print_info('The Warrior framework branch is{0}'.format(branch))
+        if os.getenv("pipmode",None) == "False":
+            print_info('The Warrior framework branch is{0}'.format(branch))
         print_info('The Warrior framework running on python version: {0} with OS: {1}'.
                    format(platform.python_version(), platform.platform()))
         print_info('Warrior script executed in host [{0}] on [{1}]'.format(hostname, date.today()))
