@@ -39,7 +39,6 @@ from warrior.Framework.ClassUtils.kafka_utils_class import WarriorKafkaProducer
 from warrior.Framework.Utils.data_Utils import getSystemData, _get_system_or_subsystem
 import warrior.Framework.Utils.email_utils as email
 from warrior.WarriorCore import warrior_cli_driver
-
 def get_testcase_details(testcase_filepath, data_repository, jiraproj):
     """Gets all the details of the Testcase
     (like title, resultsfolder, logsfolder, datafile, default on_error
@@ -125,7 +124,14 @@ def get_testcase_details(testcase_filepath, data_repository, jiraproj):
     #To check the whether data file is a well formed xml file.
     if datafile and datafile is not "NO_DATA":
         Utils.xml_Utils.getRoot(datafile)
-
+    mapfile = None
+    if 'ow_mapfile' in data_repository:
+        mapfile = data_repository['ow_mapfile']
+    elif Utils.xml_Utils.nodeExists(testcase_filepath, "MapFile"):
+        mapfile = Utils.xml_Utils.getChildTextbyParentTag(testcase_filepath, \
+                'Details', 'MapFile')
+    abs_cur_dir = os.path.dirname(testcase_filepath)
+    mapfile = Utils.file_Utils.getAbsPath(mapfile, abs_cur_dir)
     # tc_execution_dir = Utils.file_Utils.createDir_addtimestamp(execution_dir, nameonly)
     # datafile, data_type = get_testcase_datafile(testcase_filepath)
     # resultfile, resultsdir = get_testcase_resultfile(testcase_filepath, tc_execution_dir,
@@ -171,6 +177,7 @@ def get_testcase_details(testcase_filepath, data_repository, jiraproj):
     data_repository['wt_operating_system'] = operating_system.upper()
     data_repository['wt_def_on_error_action'] = def_on_error_action.upper()
     data_repository['wt_def_on_error_value'] = def_on_error_value
+    data_repository['wt_mapfile'] = mapfile
     # For custom jira project name
     if 'jiraproj' not in data_repository:
         data_repository['jiraproj'] = jiraproj
@@ -188,6 +195,8 @@ def get_testcase_details(testcase_filepath, data_repository, jiraproj):
     Utils.testcase_Utils.pCustomTag("Title", title)
     Utils.testcase_Utils.pCustomTag("TC_Location", testcase_filepath)
     Utils.testcase_Utils.pCustomTag("Datafile", datafile)
+    if mapfile:
+        Utils.testcase_Utils.pCustomTag("Mapfile", mapfile)
     Utils.testcase_Utils.pCustomTag("Logsdir", logsdir)
     Utils.testcase_Utils.pCustomTag("Defectsdir", defectsdir)
     Utils.testcase_Utils.pCustomTag("Resultfile", resultfile)
@@ -244,8 +253,9 @@ def report_testcase_result(tc_status, data_repository, tag="Steps"):
         2. data_repository (dict) = data_repository of the executed  testcase
     """
     print_info("**** Testcase Result ***")
-    print_info("TESTCASE:{0}  STATUS:{1}".format(data_repository['wt_name'],
-                                                 convertLogic(tc_status)))
+    tc_duration = Utils.data_Utils.get_object_from_datarepository("tc_duration")
+    print_info("TESTCASE:{0}  STATUS:{1} | Duration = {2}".format(data_repository['wt_name'],
+                                                 convertLogic(tc_status), tc_duration))
     print_debug("\n")
     Utils.testcase_Utils.pTestResult(tc_status, data_repository['wt_resultfile'])
     root = Utils.xml_Utils.getRoot(data_repository['wt_resultfile'])
@@ -260,11 +270,11 @@ def report_testcase_result(tc_status, data_repository, tag="Steps"):
             if fail_count == 1:
                 print_info("++++++++++++++++++++++++ Summary of Failed Keywords +++++++++++++++++++"
                            "+++++")
-                print_info("{0:15} {1:45} {2:10}".format('StepNumber', 'KeywordName', 'Status'))
-                print_info("{0:15} {1:45} {2:10}".format(str(step_num), tag+"-"+str(kw_name),
+                print_info("{0:15} {1:60} {2:10}".format('StepNumber', 'KeywordName', 'Status'))
+                print_info("{0:15} {1:60} {2:10}".format(str(step_num), tag+"-"+str(kw_name),
                                                          str(kw_status)))
             elif fail_count > 1:
-                print_info("{0:15} {1:45} {2:10}".format(str(step_num), tag+"-"+str(kw_name),
+                print_info("{0:15} {1:60} {2:10}".format(str(step_num), tag+"-"+str(kw_name),
                                                          str(kw_status)))
     print_info("=================== END OF TESTCASE ===========================")
 
@@ -547,6 +557,8 @@ def execute_testcase(testcase_filepath, data_repository, tc_context,
                                 "tc", tc_timestamp)
     tc_junit_object.update_attr("title", data_repository['wt_title'], "tc", tc_timestamp)
     tc_junit_object.update_attr("data_file", data_repository['wt_datafile'], "tc", tc_timestamp)
+    if data_repository['wt_mapfile']:
+        tc_junit_object.update_attr("mapfile", data_repository['wt_mapfile'], "tc", tc_timestamp)
 
     data_repository['wt_junit_object'] = tc_junit_object
     print_testcase_details_to_console(testcase_filepath, data_repository, steps_tag)
@@ -699,8 +711,7 @@ def execute_testcase(testcase_filepath, data_repository, tc_context,
     print_debug("[{0}] Testcase execution completed".format(tc_end_time))
     tc_duration = Utils.datetime_utils.get_time_delta(tc_start_time)
     hms = Utils.datetime_utils.get_hms_for_seconds(tc_duration)
-    print_info("Testcase duration= {0}".format(hms))
-
+    Utils.data_Utils.update_datarepository({"tc_duration" : hms})
     tc_junit_object.update_count(tc_status, "1", "ts", data_repository['wt_ts_timestamp'])
     tc_junit_object.update_count("tests", "1", "ts", data_repository['wt_ts_timestamp'])
     tc_junit_object.update_count("tests", "1", "pj", "not appicable")
@@ -716,6 +727,16 @@ def execute_testcase(testcase_filepath, data_repository, tc_context,
                                 "tc", tc_timestamp)
     tc_junit_object.update_attr("logsdir", os.path.dirname(data_repository['wt_logsdir']),
                                 "tc", tc_timestamp)
+    if data_repository.get("kafka_producer", None):
+        war_producer = data_repository.get("kafka_producer")
+        war_producer.kafka_producer.flush(60)
+        war_producer.kafka_producer.close()
+        print_info("Producer Closed connection with kafka broker")
+    elif data_repository.get("kafka_consumer", None):
+        war_consumer = data_repository.get("kafka_consumer")
+        war_consumer.kafka_consumer.close()
+        print_info("Consumer closed connection with kafka broker")
+        
     data_file = data_repository["wt_datafile"]
     system_name = ""
     try:
